Documentation
¶
Overview ¶
Package core contains basic utility functions.
Index ¶
Constants ¶
const ( Name = "bettercap" Version = "2.29bd-rc3" Author = "Simone 'evilsocket' Margaritelli" Website = "https://bettercap.org/" )
Variables ¶
This section is empty.
Functions ¶
func PopulatePreLookupTable ¶
func PopulatePreLookupTable(lookups ...string)
PopulatePreLookupTable is used to pre-populate a list of commonly used executables along with their executable paths to avoid spending time repeatedly doing this
func UniqueInts ¶
Types ¶
Click to show internal directories.
Click to hide internal directories.